import { Component, Input, OnChanges, OnInit, SimpleChanges } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { CommunityService } from '../../../services/community.service';
import { query } from '@angular/animations';

@Component({
    selector: 'app-quiz-detail',
    templateUrl: './quiz-detail.component.html',
    styleUrl: './quiz-detail.component.css',
})
export class QuizDetailComponent implements OnInit, OnChanges {
    constructor(private route: ActivatedRoute, private router: Router, private communityService: CommunityService) {}
    @Input() codeQuiz: string = '';
    title: string = '';
    description: string = '';
    nbQuestions: number = 0;
    difficulty: string = '';
    nbPlayed: number = 0;
    creator: string = '';
    showDetails: boolean = true;
    ngOnInit(): void {
        if (this.codeQuiz) {
            this.loadQuizData();
        } else {
            this.showDetails = false;
        }
    }
    ngOnChanges(changes: SimpleChanges): void {
        if (changes['codeQuiz'] && !changes['codeQuiz'].isFirstChange()) {
            this.loadQuizData();
        }
    }
    loadQuizData() {
        this.communityService.getQuizInformations(this.codeQuiz).subscribe({
            next: (data: any) => {
                this.title = data.name;
                this.description = data.description;
                this.nbQuestions = data.questions.length;
                this.difficulty = data.difficulty.name;
                this.nbPlayed = 12548;
                this.creator = data.authorId ?? 'Anonymous';
            },
        });
        this.showDetails = true;
    }
    playQuiz() {
        this.router.navigate(['/play-quiz'], { queryParams: { idQuiz: this.codeQuiz } });
    }
}
