import { Component, QueryList, ViewChildren } from '@angular/core';
import { FormBuilder, ReactiveFormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';
import { QuestionFormComponent } from '../question-form/question-form.component';

@Component({
  selector: 'app-quiz-info',
  standalone: true,
  imports: [CommonModule, ReactiveFormsModule, QuestionFormComponent],
  templateUrl: './quiz-info.component.html',
  styleUrl: './quiz-info.component.css'
})
export class QuizInfoComponent {
  @ViewChildren(QuestionFormComponent) questionForms!: QueryList<QuestionFormComponent>;

  // Controls
  titleCtrl: any;
  difficultyCtrl: any;
  quizInfoForm: any;
  // Data
  title: any;
  difficulty: any = 'medium'; // medium or database value for difficulty
  questionValid: boolean = true;


  constructor(
    private fb: FormBuilder
  ) { }

  ngOnInit(): void {
    this.titleCtrl = this.fb.control(null, []);
    this.difficultyCtrl = this.fb.control(this.difficulty, []);

    this.quizInfoForm = this.fb.group({
      title: this.titleCtrl,
      difficulty: this.difficultyCtrl,
    });

  }

  /* update Quiz Title here   */
  /* Quiz Title will be updated on the unfocus event */

  onBlurField(fieldName: string): void {
    this.title = this.quizInfoForm.get(fieldName).value;
    if (this.title) {
      console.log(`${fieldName} lost focus. Current value:`, this.title);
    }
    //add database request here
  }

  /* update Quiz Difficulty here */
  /* Quiz Difficulty will be updated on the change event */
  onFieldChange(fieldName: string): void {
    this.difficulty = this.quizInfoForm.get(fieldName).value;
    if (this.difficulty) {
      console.log(`${fieldName} changed. New value:`, this.difficulty);
    }
    //add database request here
  }

  addQuestion() {
    // check if we can add a question
    this.questionValid = this.questionForms.toArray().every((form) => form.isValid());
    if (!this.questionValid) {
      console.log('Some forms are invalid. Cannot add a new question.');
    } else {
      console.log('All forms are valid. Adding a new question...');
      // Ajoutez votre logique pour ajouter une nouvelle question
    }

  }
}
