import { ChangeDetectorRef, Component, OnInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import Swal from 'sweetalert2';
import { QuestionService } from '../../../services/question.service';
import { lastValueFrom } from 'rxjs/internal/lastValueFrom';

@Component({
    selector: 'app-play-quiz',
    templateUrl: './play-quiz.component.html',
    styleUrl: './play-quiz.component.css',
})
export class PlayQuizComponent implements OnInit {
    constructor(
        private questionSerivce: QuestionService,
        private activatedRoute: ActivatedRoute,
        private router: Router,
        private cdr: ChangeDetectorRef
    ) {}
    isLoading: boolean = false;
    quiz: any = [];
    actualQuestion: any;
    actualQuestionIndex: number = -1;
    score: number = 0;
    showNextQuestion: boolean = false;
    ngOnInit(): void {
        this.isLoading = true;
        this.activatedRoute.queryParams.subscribe((params) => {
            const idQuiz = params['idQuiz'];
            this.questionSerivce.getQuiz(idQuiz).subscribe({
                next: (data: any) => {
                    this.quiz = data;
                    this.quiz.Question;
                    this.nextQuestion();
                    this.isLoading = false;
                },
            });
        });
    }

    nextQuestion() {
        if (this.actualQuestionIndex === this.quiz.questionIndex - 1 + this.quiz.questions.length - 1) {
            Swal.fire({
                title: 'Quiz finished !',
                text: 'Want a rematch ?',
                showDenyButton: true,
                showCancelButton: false,
                confirmButtonText: 'Play again',
                confirmButtonColor: '#7e3f97',
                denyButtonColor: '#D6BAEC',
                denyButtonText: `Back home`,
            }).then((result) => {
                if (result.isConfirmed) {
                    this.actualQuestionIndex = -1;
                    this.nextQuestion();
                } else if (result.isDenied) {
                    this.router.navigate(['/']);
                }
            });
        } else {
            this.actualQuestionIndex++;
            this.actualQuestion = this.quiz.questions[this.actualQuestionIndex];
            this.randomArray(this.actualQuestion.answers);
            this.showNextQuestion = false;
        }
    }

    getAnswerBound = this.getAnswer.bind(this);

    async getAnswer(id_tested_answer: number): Promise<number> {
        this.showNextQuestion = true;
        this.cdr.detectChanges();
        let good_answer = 0;

        try {
            const data: any = await lastValueFrom(
                this.questionSerivce.getAnswer(this.quiz.id, this.actualQuestion.id, id_tested_answer)
            );
            console.log('data: ', data);
            this.score = data.score;
            good_answer = data.answers.find((answer: any) => answer.isCorrect).id;
        } catch (error) {
            console.error('Error fetching answer: ', error);
        }

        return good_answer;
    }

    goHome() {
        Swal.fire({
            title: 'Would you like to return to the menu ?',
            icon: 'warning',
            showCancelButton: true,
            confirmButtonColor: '#3085d6',
            cancelButtonColor: '#d33',
            confirmButtonText: 'BACK TO MENU',
        }).then((result) => {
            if (result.isConfirmed) {
                this.router.navigate(['/']);
            }
        });
    }

    randomArray(array: any[]): void {
        for (let i = array.length - 1; i > 0; i--) {
            const j = Math.floor(Math.random() * (i + 1));
            [array[i], array[j]] = [array[j], array[i]];
        }
    }
}
