import { Component, OnInit } from '@angular/core';
import { AbstractControl, FormArray, FormBuilder, FormGroup, ValidationErrors, Validators } from '@angular/forms';
import { Router } from '@angular/router';
import Swal from 'sweetalert2';

@Component({
    templateUrl: './create-custom-quiz.component.html',
    styleUrl: './create-custom-quiz.component.css',
})
export class CreateCustomQuizComponent implements OnInit {
    quizForm: FormGroup;
    router: any;
    constructor(
        private fb: FormBuilder,
        router: Router
    ) {
        this.quizForm = this.fb.group({
            title: this.fb.control('', [Validators.required, Validators.maxLength(255)]),
            difficulty: this.fb.control('medium', [Validators.required]),
            questions: this.fb.array([this.createQuestion()], [Validators.required]),
        });
    }
    ngOnInit(): void { }

    get questions(): FormArray {
        return this.quizForm.get('questions') as FormArray;
    }

    getAnswers(i: number): FormArray {
        return this.questions.at(i).get('answers') as FormArray;
    }

    createQuestion() {
        return this.fb.group({
            question: this.fb.control('', [Validators.required, Validators.maxLength(255)]),
            answers: this.fb.array(
                [this.createAnswer(), this.createAnswer()],
                [Validators.required, Validators.minLength(2), Validators.maxLength(4), this.answersValidators]
            ),
        });
    }

    createAnswer() {
        return this.fb.group({
            answer: this.fb.control('', [Validators.required, Validators.maxLength(255)]),
            right_answer: this.fb.control(true, [Validators.required]),
        });
    }
    addAnswer(i: number) {
        (this.questions.at(i).get('answers') as FormArray).push(this.createAnswer());
    }

    removeAnswer(i: number, j: number) {
        this.getAnswers(i).removeAt(j);
    }

    addQuestion() {
        this.questions.push(this.createQuestion());
    }

    removeQuestion(i: number) {
        Swal.fire({
            title: "Are you sure you want to delete this question?",
            text: "You won't be able to revert this!",
            icon: "warning",
            showCancelButton: true,
            confirmButtonColor: "#3085d6",
            cancelButtonColor: "#d33",
            confirmButtonText: "Yes, delete it!"
        }).then((result) => {
            if (result.isConfirmed) {
                this.questions.removeAt(i);
            }
        });
    }

    answersValidators(formArray: AbstractControl): ValidationErrors | null {
        const answersValues = formArray.value.map((answer: any) => answer.answer.toLowerCase()).filter((answer: string) => answer.trim() !== '');
        // check if the text already exist in another answer
        const hasDuplicates = answersValues.some((name: string, index: number) => answersValues.indexOf(name.toLowerCase()) !== index);
        // check if the text is empty
        const hasEmpty = answersValues.some((name: string) => name.trim() === '');
        return { duplicateAnswer: hasDuplicates, emptyAnswer: hasEmpty };
    }

    createQuiz() {
        if (this.quizForm.valid) {
            console.log(this.quizForm.value);
            this.router.navigate(['profile/']);
        } else {
            Swal.fire({
                icon: 'error',
                title: 'Oops...',
                text: 'Please fill all the required fields!',
            });
            console.log(this.quizForm.value);
        }
    }
}
